        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 31 <br>1,3,5,6,8,9,12,15,16,17,21,22,23,24,25,26,30,31,32,33,34,35,36,38,40,41,42,43,46,47,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,10,11,13,14,18,19,20,27,28,29,37,39,44,45,48,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 31 <br>1,3,5,6,8,9,12,15,16,17,21,22,23,24,25,26,30,31,32,33,34,35,36,38,40,41,42,43,46,47,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,10,11,13,14,18,19,20,27,28,29,37,39,44,45,48,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 31 <br>1,3,5,6,8,9,12,15,16,17,21,22,23,24,25,26,30,31,32,33,34,35,36,38,40,41,42,43,46,47,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,10,11,13,14,18,19,20,27,28,29,37,39,44,45,48,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 31 <br>1,3,5,6,8,9,12,15,16,17,21,22,23,24,25,26,30,31,32,33,34,35,36,38,40,41,42,43,46,47,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,10,11,13,14,18,19,20,27,28,29,37,39,44,45,48,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 31 <br>1,3,5,6,8,9,12,15,16,17,21,22,23,24,25,26,30,31,32,33,34,35,36,38,40,41,42,43,46,47,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260521 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,10,11,13,14,18,19,20,27,28,29,37,39,44,45,48,49';}
}
